#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2010 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
SchoolTool Niepa application views.
"""

from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.traversing.browser.absoluteurl import absoluteURL

from z3c.form import form, field, button

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.schoolyear.interfaces import ISchoolYearContainer
from schooltool.skin.skin import NavigationViewlet

from schooltool.niepa.app.app import INiepaApplicationPreferences

from schooltool.niepa import NiepaMessage as _


class ManageYearlyViewlet(NavigationViewlet):
    @property
    def schoolyear(self):
        app = ISchoolToolApplication(None)
        syc = ISchoolYearContainer(app)
        return syc.getActiveSchoolYear()

    @property
    def link(self):
        schoolyear = self.schoolyear
        if schoolyear is None:
            return ''
        return absoluteURL(schoolyear, self.request)


class NiepaSchoolInfoEditView(form.EditForm):

    template = ViewPageTemplateFile('templates/school_info_form.pt')
    description = None
    label = _('School Info')

    def fieldsets(self):
        return [
            {'id': 'identification',
             'legend': _('School Identification'),
             'rows': [
                 ['school_code'],
                 ['name'],
                 ['street'],
                 ['village'],
                 ['town'],
                 ['lga'],
                 ['state'],
                 ['telephone'],
                 ],},
            {'id': 'characteristics',
             'legend': _('School Characteristics'),
             'rows': [
                 ['year_established'],
                 ['location_coordinates'],
                 ['distance'],
                 ['levels_offered'],
                 ['school_type'],
                 ['shifts'],
                 ['shared_facilities'],
                 ['development_plan'],
                 ['sbmc'],
                 ['parent_forum'],
                 ['last_inspection'],
                 ['inspection_authority'],
                 ],},
             ]

    def __init__(self, *args, **kw):
        super(NiepaSchoolInfoEditView, self).__init__(*args, **kw)
        self.fields = field.Fields(INiepaApplicationPreferences).omit(
            'timezone', 'timeformat', 'dateformat', 'weekstart',
            'title', 'frontPageCalendar')

    def nextURL(self):
        return absoluteURL(self.context, self.request) + '/manage.html'

    @button.buttonAndHandler(_('Apply'))
    def handle_apply(self, action):
        data, errors = self.extractData()
        if errors:
            self.status = self.formErrorsMessage
            return
        self.applyChanges(data)
        self.request.response.redirect(self.nextURL())

    @button.buttonAndHandler(_('Cancel'))
    def handle_cancel_action(self, action):
        self.request.response.redirect(self.nextURL())

    def updateActions(self):
        super(NiepaSchoolInfoEditView, self).updateActions()
        self.actions['apply'].addClass('button-ok')
        self.actions['cancel'].addClass('button-cancel')

