#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2010 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Cambodia person table formatters
"""

from zope.catalog.interfaces import ICatalog
from zope.component import getUtility
from zope.intid.interfaces import IIntIds
from zc.table import table
from zope.app.pagetemplate import ViewPageTemplateFile

from schooltool.person.browser.person import PersonFilterWidget
from schooltool.person.browser.person import PersonTableFormatter
from schooltool.table.batch import Batch


class FilterByGroupFilterWidget(PersonFilterWidget):

    template = ViewPageTemplateFile('templates/person_filter.pt')

    def filter(self, items):
        if 'CLEAR_SEARCH' in self.request:
            self.request.form['SEARCH_TITLE'] = ''
        if self.group is None:
            return []
        available_members = self.getAvailableMembers()
        int_ids = getUtility(IIntIds)
        keys = set([int_ids.queryId(person) for person in available_members])
        items = [item for item in items if item['id'] in keys]
        catalog = ICatalog(self.context)
        title_index = catalog['title']
        username_index = catalog['__name__']
        if 'SEARCH_TITLE' in self.request:
            searchstr = self.request['SEARCH_TITLE'].lower()
            results = []
            for item in items:
                title = title_index.documents_to_values[item['id']]
                username = username_index.documents_to_values[item['id']]
                if (searchstr in title.lower() or
                    searchstr in username.lower()):
                    results.append(item)
            items = results
        return items

    def getAvailableMembers(self):
        return self.group.members

    def getGroup(self):
        return getattr(self, '_group')

    def setGroup(self, group):
        self._group = group

    group = property(getGroup, setGroup)


class FilterByGroupTableFormatter(PersonTableFormatter):

    filter_widget_class = FilterByGroupFilterWidget

    def setUp(self, items=None, ommit=[], filter=None, columns=None,
              columns_before=[], columns_after=[], sort_on=None, prefix='',
              formatters=[], table_formatter=table.FormFullFormatter,
              batch_size=25):
        if items is not None:
            items = self.indexItems(items)
        self.filter_widget = self.getFilterWidget()
        self._table_formatter = table_formatter
        if not columns:
            columns = self.columns()
        if formatters:
            for formatter, column in zip(formatters, columns):
                column.cell_formatter = formatter
        self._columns = columns_before[:] + columns[:] + columns_after[:]
        if items is None:
            items = self.items()
        if not filter:
            filter = self.filter
        self._items = filter(self.ommit(items, ommit))
        self.prefix = prefix
        if batch_size == 0:
            batch_size = len(list(self._items))
        self.batch = Batch(self, batch_size=batch_size)
        self._sort_on = sort_on or self.sortOn()

    def getFilterWidget(self):
        widget = self.filter_widget_class(self.context, self.request)
        widget.group = self.group
        return widget

    def getGroup(self):
        return getattr(self, '_group')

    def setGroup(self, group):
        self._group = group

    group = property(getGroup, setGroup)

